@@ -156,10 +156,14 @@ def get_site_packages_dir(*dirs):
 
     @param dirs: directory names to be appended
     """
-
+    python_version = sys.version_info[:2]
     libdir = get_python_lib(plat_specific=False,
                             standard_lib=True, prefix='')
-    return os.path.join(libdir, 'site-packages', *dirs)
+    if python_version < (2, 6):
+        site = 'site-packages'
+    else:
+        site = 'dist-packages'
+    return os.path.join(libdir, site, *dirs)
 
 def listfiles(*dirs):
     """
