@@ -86,7 +86,7 @@ class ProxyWidgetMixin(object):
     gsignal('validation-changed', bool)
     gsignal('validate', object, retval=object)
 
-    gproperty('data-type', object, blurb='Data Type')
+    gproperty('data-type', str, blurb='Data Type')
     gproperty('model-attribute', str, blurb='Model attribute')
 
     allowed_data_types = ()
@@ -100,6 +100,7 @@ class ProxyWidgetMixin(object):
             raise TypeError("%s.allowed_data_types must be a tuple" % (
                 self.allowed_data_types))
         self._data_format = None
+        self._converter_options = {}
 
     # Properties
 
@@ -112,25 +113,33 @@ class ProxyWidgetMixin(object):
         """
         if data_type is None:
             return data_type
+        elif data_type == '':
+            return None
 
         # This may convert from string to type,
         # A type object will always be returned
         data_type = converter.check_supported(data_type)
-
-        if not issubclass(data_type, self.allowed_data_types):
-            raise TypeError(
-                "%s only accept %s types, not %r"
-                % (self,
-                   ' or '.join([t.__name__ for t in self.allowed_data_types]),
-                   data_type))
-
         self._converter = converter.get_converter(data_type)
-        return data_type
+        return self._converter.type.__name__
 
     # Public API
     def set_data_format(self, format):
         self._data_format = format
 
+    def set_options_for_datatype(self, datatype, **options):
+        """Set some options to be passed to the datatype converter.
+        Any additional parameter will be passed the the converter when
+        converting an object to a string, for displaying in the widget. Note
+        that the converter.as_string method should be able to handle such
+        parameters.
+
+        @param datatype: the datatype.
+        """
+        if not options:
+            raise ValueError
+
+        self._converter_options[datatype] = options
+
     def read(self):
         """Get the content of the widget.
         The type of the return value
@@ -141,6 +150,7 @@ class ProxyWidgetMixin(object):
 
     def update(self, value):
         """
+        Update the content value of the widget.
         @param value:
         """
         raise NotImplementedError
@@ -155,7 +165,8 @@ class ProxyWidgetMixin(object):
         if conv is None:
             conv = converter.get_converter(str)
 
-        return conv.as_string(data, format=self._data_format)
+        return conv.as_string(data, format=self._data_format,
+                              **self._converter_options.get(conv.type,{}))
 
     def _from_string(self, data):
         """Convert a string to the data type of the widget
@@ -216,6 +227,7 @@ class ValidatableProxyWidgetMixin(ProxyWidgetMixin):
 
     def is_valid(self):
         """
+        Verify the widget state.
         @returns: True if the widget is in validated state
         """
         return self._valid
